@@ -1,3 +1,4 @@
+import sys
 from dataclasses import dataclass
 from math import floor
 from string import Formatter
@@ -16,9 +17,19 @@ __all__ = [
 ]
 
 
+# We use this as maximum length for the tokenizer in case we are not
+# truncating; we need this otherwise huggingface prints a warning.
+# Using sys.maxsize from here: https://stackoverflow.com/a/7604981/938048
+INT_MAX_LENGTH = sys.maxsize
+
+
 class EncodeFieldsMapper(SingleBaseMapper):
     """Simply encodes the fields in the input data using the tokenizer."""
 
+    tokenizer: PreTrainedTokenizerBase
+    is_split_into_words: bool
+    fields_to_encode: Dict[str, None]
+
     def __init__(
         self,
         fields_to_encode: Sequence[str],
@@ -36,7 +47,12 @@ class EncodeFieldsMapper(SingleBaseMapper):
 
         self.tokenizer = tokenizer
         self.is_split_into_words = is_split_into_words
-        self.fields_to_encode = set(fields_to_encode)
+        # @soldni: using `dict.fromkeys` in place of `frozenset` to avoid
+        # issues with hashability: sets are not guaranteed to have the
+        # same hash, which causes issues when trying to cache through
+        # huggingface datasets.
+        self.fields_to_encode = dict.fromkeys(fields_to_encode)
+
         super().__init__(
             input_fields=fields_to_encode,
             output_fields=fields_to_encode,
@@ -47,6 +63,11 @@ class EncodeFieldsMapper(SingleBaseMapper):
             name: (
                 self.tokenizer(
                     field,
+                    # we are not really truncating given the value of
+                    # max length, but we need to pass something to avoid
+                    # a warning from huggingface
+                    truncation=True,
+                    max_length=INT_MAX_LENGTH,
                     add_special_tokens=False,
                     return_attention_mask=False,
                     return_token_type_ids=False,
@@ -117,8 +138,8 @@ class TruncateNFieldsMapper(SingleBaseMapper):
             )
 
         self.tokenizer = tokenizer
-        self.fields_to_truncate = sorted(set(fields_to_truncate))
-        self.fields_to_preserve = sorted(set(fields_to_preserve or []))
+        self.fields_to_truncate = tuple(sorted(set(fields_to_truncate)))
+        self.fields_to_preserve = tuple(sorted(set(fields_to_preserve or [])))
         self.max_length = max_length - length_penalty
         self.strategy = strategy
         super().__init__(
@@ -340,6 +361,8 @@ class FillEncodedPromptMapper(SingleBaseMapper, GetTokenizerOutputFieldsMixin):
         output_prefix: Optional[str] = None,
         return_attention_mask: bool = True,
         return_token_type_ids: bool = False,
+        add_bos_token: bool = True,
+        add_eos_token: bool = True,
     ) -> None:
         self.tokenizer = tokenizer
         self._prefix = output_prefix
@@ -348,10 +371,14 @@ class FillEncodedPromptMapper(SingleBaseMapper, GetTokenizerOutputFieldsMixin):
         self.return_token_type_ids = return_token_type_ids
 
         self.bos_token_ids = (
-            [] if tokenizer.bos_token_id is None else [tokenizer.bos_token_id]
+            []
+            if tokenizer.bos_token_id is None or not add_bos_token
+            else [tokenizer.bos_token_id]
         )
         self.eos_token_ids = (
-            [] if tokenizer.eos_token_id is None else [tokenizer.eos_token_id]
+            []
+            if tokenizer.eos_token_id is None or not add_eos_token
+            else [tokenizer.eos_token_id]
         )
 
         self.prompt = PromptSegment.from_template(
