@@ -28,6 +28,9 @@ class UnpackingMapper(BatchedBaseMapper):
     _DRP_EXTRA = "drop"
     _RPT_EXTRA = "repeat"
 
+    fields_to_unpack: Optional[Dict[str, None]]
+    fields_to_ignore: Optional[Dict[str, None]]
+
     def __init__(
         self,
         fields_to_unpack: Optional[List[str]] = None,
@@ -69,23 +72,39 @@ class UnpackingMapper(BatchedBaseMapper):
             )
 
         if fields_to_unpack is not None:
-            field_names = set(fields_to_unpack)
-            self.check_unpack_fn = lambda f: f in field_names
+            # @soldni: using `dict.fromkeys` in place of `frozenset` to avoid
+            # issues with hashability: sets are not guaranteed to have the
+            # same hash, which causes issues when trying to cache through
+            # huggingface datasets.
+            self.fields_to_unpack = dict.fromkeys(fields_to_unpack)
+            self.fields_to_ignore = None
+
         elif fields_to_ignore is not None:
-            field_names = set(fields_to_ignore)
-            self.check_unpack_fn = lambda f: f not in field_names
+            self.fields_to_unpack = None
+            # @soldni: using `dict.fromkeys` in place of `frozenset` to avoid
+            # issues with hashability: sets are not guaranteed to have the
+            # same hash, which causes issues when trying to cache through
+            # huggingface datasets.
+            self.fields_to_ignore = dict.fromkeys(fields_to_ignore)
+
         else:
-            field_names = None
-            # unpack all!
-            self.check_unpack_fn = lambda _: True
+            self.fields_to_unpack = self.fields_to_ignore = None
 
         self.ignore_behavior = ignored_behavior
 
         super().__init__(
-            input_fields=list(field_names) if field_names else None,
-            output_fields=list(field_names) if field_names else None,
+            input_fields=(fields_to_unpack or []) + (fields_to_ignore or []),
+            output_fields=(fields_to_unpack or []) + (fields_to_ignore or []),
         )
 
+    def _check_wether_to_unpack(self, field_name: str) -> bool:
+        if self.fields_to_unpack is not None:
+            return field_name in self.fields_to_unpack
+        elif self.fields_to_ignore is not None:
+            return field_name not in self.fields_to_ignore
+        else:
+            return True
+
     def transform(
         self, data: Iterable[TransformElementType]
     ) -> Iterable[TransformElementType]:
@@ -100,7 +119,9 @@ class UnpackingMapper(BatchedBaseMapper):
             # first, compute the names of fields to unpack
             if all_field_names_to_unpack is None:
                 all_field_names_to_unpack = [
-                    k for k in packed_sample.keys() if self.check_unpack_fn(k)
+                    k
+                    for k in packed_sample.keys()
+                    if self._check_wether_to_unpack(k)
                 ]
 
             if len(all_field_names_to_unpack) == 0:
